import { Transaction } from 'sequelize';
import { Model } from 'sequelize-typescript';
import { MRunnerJob, MRunnerJobRunner, MRunnerJobRunnerParent } from '../../types/models/runners';
import { RunnerJob, RunnerJobAdmin, RunnerJobPayload, RunnerJobPrivatePayload, RunnerJobState, RunnerJobType } from '../../../shared/models';
import { AttributesOnly } from '../../../shared/typescript-utils';
import { RunnerModel } from './runner';
export declare class RunnerJobModel extends Model<Partial<AttributesOnly<RunnerJobModel>>> {
    uuid: string;
    type: RunnerJobType;
    payload: RunnerJobPayload;
    privatePayload: RunnerJobPrivatePayload;
    state: RunnerJobState;
    failures: number;
    error: string;
    priority: number;
    processingJobToken: string;
    progress: number;
    startedAt: Date;
    finishedAt: Date;
    createdAt: Date;
    updatedAt: Date;
    dependsOnRunnerJobId: number;
    DependsOnRunnerJob: RunnerJobModel;
    runnerId: number;
    Runner: RunnerModel;
    static loadWithRunner(uuid: string): Promise<MRunnerJobRunner>;
    static loadByRunnerAndJobTokensWithRunner(options: {
        uuid: string;
        runnerToken: string;
        jobToken: string;
    }): Promise<MRunnerJobRunner>;
    static listAvailableJobs(): Promise<MRunnerJob[]>;
    static listStalledJobs(options: {
        staleTimeMS: number;
        types: RunnerJobType[];
    }): Promise<MRunnerJob[]>;
    static listChildrenOf(job: MRunnerJob, transaction?: Transaction): Promise<MRunnerJob[]>;
    static listForApi(options: {
        start: number;
        count: number;
        sort: string;
        search?: string;
    }): Promise<{
        total: number;
        data: MRunnerJobRunnerParent[];
    }>;
    static updateDependantJobsOf(runnerJob: MRunnerJob): Promise<[affectedCount: number]>;
    static cancelAllJobs(options: {
        type: RunnerJobType;
    }): Promise<[affectedCount: number]>;
    resetToPending(): void;
    setToErrorOrCancel(state: RunnerJobState.PARENT_ERRORED | RunnerJobState.ERRORED | RunnerJobState.CANCELLED | RunnerJobState.PARENT_CANCELLED): void;
    toFormattedJSON(this: MRunnerJobRunnerParent): RunnerJob;
    toFormattedAdminJSON(this: MRunnerJobRunnerParent): RunnerJobAdmin;
}
//# sourceMappingURL=runner-job.d.ts.map